@@ -54,9 +54,6 @@
 
 #define PFX "iscsi_ipc "
 
-/* TODO fix me */
-#define IFNAMSIZ 15
-
 #include "nic.h"
 #include "nic_utils.h"
 #include "nic_vlan.h"
@@ -1245,7 +1242,8 @@ void iscsid_cleanup()
 {
 	int rc;
 
-	if (iscsid_opts.fd != INVALID_FD) {
+	if (iscsid_opts.fd != INVALID_FD &&
+	    iscsid_opts.thread != INVALID_THREAD) {
 		rc = pthread_cancel(iscsid_opts.thread);
 		if (rc != 0) {
 			LOG_ERR("Could not cancel iscsid listening thread: %s",
