@@ -44,7 +44,10 @@
 #include "idbm.h"
 #include "default.h"
 
-#define ISCSIUIO_PATH		"/sbin/iscsiuio"
+#ifndef SBINDIR
+#define SBINDIR "/sbin"
+#endif
+#define ISCSIUIO_PATH SBINDIR "/iscsiuio"
 
 struct _iscsi_net_drv {
 	const char *net_driver_name;		// Ethernet driver.
