@@ -43,11 +43,11 @@ static const char acl_authmethod_set_chap_alg_list[] = "CHAP";
 static const char acl_reject_option_name[] = "Reject";
 
 #include <openssl/evp.h>
+#include <openssl/rand.h>
 static int auth_hash_init(EVP_MD_CTX **context, int chap_alg);
 static void auth_hash_update(EVP_MD_CTX *context, unsigned char *md, unsigned int);
 static unsigned int auth_hash_final(unsigned char *, EVP_MD_CTX *context);
 
-void get_random_bytes(unsigned char *data, unsigned int length);
 size_t strlcpy(char *, const char *, size_t);
 size_t strlcat(char *, const char *, size_t);
 
@@ -109,7 +109,7 @@ acl_chap_auth_request(struct iscsi_acl *client, char *username, unsigned int id,
 	unsigned char verify_data[client->chap_challenge_len];
 
 	/* the expected credentials are in the session */
-	if (session->username_in == NULL) {
+	if (session->username_in[0] == '\0') {
 		log_error("failing authentication, no incoming username "
 			  "configured to authenticate target %s",
 			  session->target_name);
@@ -122,7 +122,6 @@ acl_chap_auth_request(struct iscsi_acl *client, char *username, unsigned int id,
 	}
 
 	if ((session->password_in_length < 1) ||
-	    (session->password_in == NULL) ||
 	    (session->password_in[0] == '\0')) {
 		log_error("failing authentication, no incoming password "
 		       "configured to authenticate target %s",
@@ -217,42 +216,6 @@ static unsigned int auth_hash_final(unsigned char *hash, EVP_MD_CTX *context) {
 	return md_len;
 }
 
-void
-get_random_bytes(unsigned char *data, unsigned int length)
-{
-
-	long r;
-        unsigned n;
-	int fd, r_size = sizeof(r);
-
-	fd = open("/dev/urandom", O_RDONLY);
-        while (length > 0) {
-
-		if (fd == -1 || read(fd, &r, r_size) != r_size)
-			r = rand();
-                r = r ^ (r >> 8);
-                r = r ^ (r >> 4);
-                n = r & 0x7;
-
-		if (fd == -1 || read(fd, &r, r_size) != r_size)
-			r = rand();
-                r = r ^ (r >> 8);
-                r = r ^ (r >> 5);
-                n = (n << 3) | (r & 0x7);
-
-		if (fd == -1 || read(fd, &r, r_size) != r_size)
-			r = rand();
-                r = r ^ (r >> 8);
-                r = r ^ (r >> 5);
-                n = (n << 2) | (r & 0x3);
-
-                *data++ = n;
-                length--;
-        }
-	if (fd)
-		close(fd);
-}
-
 static const char acl_none_option_name[] = "None";
 
 static int
@@ -1008,6 +971,7 @@ acl_rmt_auth(struct iscsi_acl *client)
 	enum auth_dbg_status dbg_status;
 	const char *chap_rsp_key_val;
 	const char *chap_username_key_val;
+	int ssl_ret = 0;
 
 	switch (client->rmt_state) {
 	case AUTH_RMT_STATE_SEND_ALG:
@@ -1023,7 +987,13 @@ acl_rmt_auth(struct iscsi_acl *client)
 			client->rmt_state = AUTH_RMT_STATE_DONE;
 			break;
 		}
-		get_random_bytes(id_data, 1);
+
+		ssl_ret = RAND_bytes(id_data, sizeof(id_data));
+		if (ssl_ret != 1) {
+			client->rmt_state = AUTH_RMT_STATE_ERROR;
+			client->dbg_status = AUTH_DBG_STATUS_AUTH_FAIL;
+			break;
+		}
 		client->send_chap_identifier = id_data[0];
 		snprintf(client->scratch_key_value, AUTH_STR_MAX_LEN, "%lu",
 			 (unsigned long)client->send_chap_identifier);
@@ -1032,8 +1002,13 @@ acl_rmt_auth(struct iscsi_acl *client)
 				  client->scratch_key_value);
 
 		client->send_chap_challenge.length = client->chap_challenge_len;
-		get_random_bytes(client->send_chap_challenge.large_binary,
-				 client->send_chap_challenge.length);
+		ssl_ret = RAND_bytes(client->send_chap_challenge.large_binary,
+				     client->send_chap_challenge.length);
+		if (ssl_ret != 1) {
+			client->rmt_state = AUTH_RMT_STATE_ERROR;
+			client->dbg_status = AUTH_DBG_STATUS_AUTH_FAIL;
+			break;
+		}
 		acl_set_key_value(&client->send_key_block,
 				  AUTH_KEY_TYPE_CHAP_CHALLENGE, "");
 
