@@ -387,7 +387,7 @@ free_ifaces:
 	return rc;
 }
 
-static void isns_reg_refresh_with_disc(void *data)
+static void isns_reg_refresh_with_disc(__attribute__((unused))void *data)
 {
 	int retries = 0, rc;
 
@@ -488,7 +488,7 @@ static void isns_reg_refresh_by_eid_qry(void *data)
 	int status, timeout;
 
 	log_debug(1, "Refresh registration using eid qry");
-	if (refresh_data->start_time + refresh_data->interval <= time(NULL)) {
+	if ((time_t)(refresh_data->start_time + refresh_data->interval) <= time(NULL)) {
 		log_error("Could not refresh registration with server "
 			  "before registration period. Starting new "
 			  "registration.");
@@ -551,7 +551,7 @@ static int isns_setup_registration_refresh(isns_simple_t *rsp, int poll_inval)
 {
 	isns_object_list_t objs = ISNS_OBJECT_LIST_INIT;
 	struct isns_refresh_data *refresh_data;
-	int status, i, rc = 0;
+	int status, rc = 0;
 	uint32_t interval = 0;
 
 	status = isns_query_response_get_objects(rsp, &objs);
@@ -562,7 +562,7 @@ static int isns_setup_registration_refresh(isns_simple_t *rsp, int poll_inval)
 		return ISCSI_ERR;
 	}
 
-	for (i = 0; i < objs.iol_count; ++i) {
+	for (unsigned int i = 0; i < objs.iol_count; ++i) {
 		isns_object_t *obj = objs.iol_data[i]; 
 
 		if (!isns_object_is_entity(obj))
@@ -605,7 +605,7 @@ static int isns_setup_registration_refresh(isns_simple_t *rsp, int poll_inval)
 
 	if (poll_inval > 0) {
 		/* user wants to override server and do disc */
-		if (isns_refresh_interval > poll_inval)
+		if ((int)isns_refresh_interval > poll_inval)
 			isns_refresh_interval = poll_inval;
 		isns_add_timer(isns_refresh_interval,
 			       isns_reg_refresh_with_disc,
@@ -831,9 +831,11 @@ done:
 	return rc;
 }
 
-static void isns_scn_callback(isns_db_t *db, uint32_t bitmap,
-			      isns_object_template_t *node_type,
-			      const char *node_name, const char *dst_name)
+static void isns_scn_callback(__attribute__((unused))isns_db_t *db,
+			      uint32_t bitmap,
+			      __attribute__((unused))isns_object_template_t *node_type,
+			      const char *node_name,
+			      const char *dst_name)
 {
 	log_error("SCN for initiator: %s (Target: %s, Event: %s.)",
 		    dst_name, node_name, isns_event_string(bitmap));
@@ -1034,11 +1036,6 @@ static void __do_st_disc_and_login(struct discovery_rec *drec)
 	drec->u.sendtargets.reopen_max = 0;
 
 	iface_link_ifaces(&setup_ifaces);
-	/*
-	 * disc code assumes this is not set and wants to use
-	 * the userspace IO code.
-	 */
-	ipc = NULL;
 
 	rc = idbm_bind_ifaces_to_nodes(discovery_sendtargets, drec,
 					&setup_ifaces, &rec_list);
@@ -1057,7 +1054,7 @@ free_ifaces:
 	}
 }
 
-static void do_st_disc_and_login(const char *def_iname,
+static void do_st_disc_and_login(__attribute__((unused))const char *def_iname,
 				 struct discovery_rec *drec, int poll_inval)
 {
 	if (poll_inval < 0)
@@ -1072,7 +1069,8 @@ static void do_st_disc_and_login(const char *def_iname,
 	discoveryd_stop();
 }
 
-static int st_start(void *data, struct discovery_rec *drec)
+static int st_start(__attribute__((unused))void *data,
+		    struct discovery_rec *drec)
 {
 	log_debug(1, "st_start %s:%d %d", drec->address, drec->port,
 		  drec->u.sendtargets.use_discoveryd);
