@@ -46,7 +46,7 @@ static void iscsid_startup(void)
 	if (!startup_cmd) {
 		log_error("iscsid is not running. Could not start it up "
 			  "automatically using the startup command in the "
-			  "/etc/iscsi/iscsid.conf iscsid.startup setting. "
+			  "iscsid.conf iscsid.startup setting. "
 			  "Please check that the file exists or that your "
 			  "init scripts have started iscsid.");
 		return;
@@ -141,12 +141,7 @@ int iscsid_response(int fd, iscsiadm_cmd_e cmd, iscsiadm_rsp_t *rsp,
 	size_t len = sizeof(*rsp);
 	int iscsi_err = ISCSI_ERR_ISCSID_COMM_ERR;
 	int err;
-	int poll_wait = 0;
 
-	if (timeout == -1) {
-		timeout = ISCSID_REQ_TIMEOUT;
-		poll_wait = 1;
-	}
 	while (len) {
 		struct pollfd pfd;
 
@@ -154,9 +149,7 @@ int iscsid_response(int fd, iscsiadm_cmd_e cmd, iscsiadm_rsp_t *rsp,
 		pfd.events = POLLIN;
 		err = poll(&pfd, 1, timeout);
 		if (!err) {
-			if (poll_wait)
-				continue;
-			return ISCSI_ERR_SESSION_NOT_CONNECTED;
+			return ISCSI_ERR_REQ_TIMEDOUT;
 		} else if (err < 0) {
 			if (errno == EINTR)
 				continue;
